@@ -72,6 +72,14 @@ public:
      * I.e. resets revealed state
      */
     void unreveal() { m_state = KMinesState::Released; updatePixmap(); }
+    /**
+     * Removes the flag
+     */
+    void unflag();
+    /**
+     * Stops the mine from being exploded
+     */
+    void unexplode();
     /**
      * @return whether this cell is revealed
      */
